==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2107_155.zip: ronportal/ronportal/kapacity/kapacityfilterform.php <==
<?php
/**
 * stanislav.elbl, 07.11.2019
 */

namespace RonPortal\Kapacity;

use Ron\Controls\LinksList;
use Ron\DB\Database;
use Ron\TextManager;
use RonPortal\Controls\RonPortalFilterForm;
use RonPortal\NastaveniUzivatele;
use RonPortal\Prava;
use RonPortal\RonPortalSettings;
use RonPortal\User;


class KapacityFilterForm extends RonPortalFilterForm
{
    const REZIM_UPRAV = 'kapacity_rezimuprav';

    public $zobrazitLinkSkutecneAbsence;

    /**
     * KapacityFilterFrom constructor.
     * @param Database $database
     * @param string $action
     */
    public function __construct($database, $action = 'kapacity')
    {
        parent::__construct($database, $action, true);  // useGet = true

        // nastaveni rozdeleni je pres if ve dvou vetvich - jinak si neprenasi vybrane rozdeleni do jinych seznamu (napr. do zpracovane dochazky)
        $typRozdeleni = KapacitySettings::typRozdeleniProVyber();
        if ($typRozdeleni !== RonPortalSettings::getIntValue(RonPortalSettings::ROZDELENI_TYP)) {
            $this->f_pravarozdeleni = Prava::vratPrava('kapacity');
            $this->nastavRozdeleni(true, $typRozdeleni, 0, '', true);
        } else {
            $this->nastavRozdeleni(true);
            $this->f_pravarozdeleni = Prava::vratPrava('kapacity'); // aby se filtroval seznam rozdeleni
        }
    }


    public function nastavProPlanovaniObdobi()
    {
        $this ->nastavObdobi(true, 'ADS', false);       // jenOtevrene = false

        $this ->zobrazitLinkSkutecneAbsence =
            $this ->getAction === 'kapacity'  &&
            NastaveniUzivatele::getUserSettingsItem($this ->database, self::REZIM_UPRAV, RonPortalSettings::getIntValue('kapacity_rezim')) < 3;

        if (RonPortalSettings::getIntValue(RonPortalSettings::ROZDELENI2_TYP)) {
            $this ->nastavRozdeleni2(true);
        }
    }

    public function renderRezimZobrazeni()
    {
        if (RonPortalSettings::getIntValue(KapacitySettings::POVOLIT_REZIM_UPRAV)) {
            $data = [
                0 => TextManager::_('Puvodni_plan'),
                1 => TextManager::_('Upraveny_plan'),
                2 => TextManager::_('Kombinovany_plan'),
                3 => TextManager::_('Kapacity_dle_smen')
            ];
        } else {
            $data = [
                0 => TextManager::_('Puvodni_plan'),
                3 => TextManager::_('Kapacity_dle_smen')
            ];
        }

        if (RonPortalSettings::getIntValue('kapacity_povolitsloty')) {
            $data[4] = TextManager::_('Prehled_podle_slotu');
        }

        if (RonPortalSettings::getIntValue('planovanipodminek')) {
            $data[5] = TextManager::_('Planovani_podminek');
        }

        echo '<div class="filterrow" id="filter_urovenschvaleni">';
        echo '<span class="filtercaption"></span>';
        LinksList::renderLinks($data,
            NastaveniUzivatele::getUserSettingsItem($this ->database, self::REZIM_UPRAV, RonPortalSettings::getIntValue('kapacity_rezim')),
            '?menuid=kapacity&rezim=', '', false);
        echo "</div>\n";
    }


    public function renderSkutecneAbsence()
    {
        echo '<div class="filterrow" id="filter_urovenschvaleni">';
        echo '<span class="filtercaption"></span>';

        if (KapacityController::getZobrazitSkuteneAbsence()) {
            echo "<a href='?menuid=kapacity&skutecneabsence=0'>" . TextManager::_('Skryt_skutecne_absence') . "</a>";
        } else {
            echo "<a href='?menuid=kapacity&skutecneabsence=1'>" . TextManager::_('Zobrazit_skutecne_absence') . "</a>";
        }

        echo "</div>\n";
    }


    public function renderFilters()
    {
        parent::renderFilters();

        if (User::isAuthenticated()) {
            $this->renderRezimZobrazeni(); // prepinani zobrazeni
        }

        if ($this ->zobrazitLinkSkutecneAbsence) {
            $this ->renderSkutecneAbsence();
        }
    }

}

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2311_175.zip: ronportal/ronportal/kapacity/kapacityfilterform.php <==
<?php
/**
 * stanislav.elbl, 07.11.2019
 */

namespace RonPortal\Kapacity;

use Ron\Controls\LinksList;
use Ron\DB\Database;
use Ron\TextManager;
use RonPortal\Controls\FilterFormFilterRozdeleni;
use RonPortal\Controls\RonPortalFilterForm;
use RonPortal\NastaveniUzivatele;
use RonPortal\Prava;
use RonPortal\RonPortalSettings;
use RonPortal\User;


class KapacityFilterForm extends RonPortalFilterForm
{
    const REZIM_UPRAV = 'kapacity_rezimuprav';

    public $zobrazitLinkSkutecneAbsence;

    /**
     * KapacityFilterFrom constructor.
     * @param Database $database
     * @param string $action
     */
    public function __construct($database, $action = 'kapacity')
    {
        parent::__construct($database, $action, true);  // useGet = true

        // nastaveni rozdeleni je pres if ve dvou vetvich - jinak si neprenasi vybrane rozdeleni do jinych seznamu (napr. do zpracovane dochazky)
        $typRozdeleni = KapacitySettings::typRozdeleniProVyber();

        if ($typRozdeleni !== RonPortalSettings::getIntValue(RonPortalSettings::ROZDELENI_TYP)) {
            // planovani kapacit ma jiny typ rozdeleni nez je standardni typ
            $this ->addFilterRozdeleni(
                (new FilterFormFilterRozdeleni($this, 'rozdeleni'))
                    ->setTypRozdeleni($typRozdeleni)
                    ->setSessionName('ads_rozdeleni_' . $typRozdeleni)
                    ->setUserSettingsName('ads_rozdeleni_' . $typRozdeleni)
                    ->setPrava(Prava::vratPrava('kapacity'))
            );
        } else {
            $this ->addFilterRozdeleni1(null, Prava::vratPrava('kapacity'));
        }

//        if ($typRozdeleni !== RonPortalSettings::getIntValue(RonPortalSettings::ROZDELENI_TYP)) {
//            $this->f_pravarozdeleni = Prava::vratPrava('kapacity');
//            $this->nastavRozdeleni(true, $typRozdeleni, 0, '', true);
//        } else {
//            $this->nastavRozdeleni(true);
//            $this->f_pravarozdeleni = Prava::vratPrava('kapacity'); // aby se filtroval seznam rozdeleni
//        }
    }


    public function nastavProPlanovaniObdobi()
    {
        $this ->nastavObdobi(true, 'ADS', false);       // jenOtevrene = false

        $this ->zobrazitLinkSkutecneAbsence =
            $this ->getAction === 'kapacity'  &&
            NastaveniUzivatele::getUserSettingsItem($this ->database, self::REZIM_UPRAV, RonPortalSettings::getIntValue('kapacity_rezim')) < 3;

        if (RonPortalSettings::getIntValue(RonPortalSettings::ROZDELENI2_TYP)) {
            $this ->addFilterRozdeleni2(null, Prava::vratPrava('kapacity'));
            //$this ->nastavRozdeleni2(true);
        }
    }

    public function renderRezimZobrazeni()
    {
        if (RonPortalSettings::getIntValue(KapacitySettings::POVOLIT_REZIM_UPRAV)) {
            $data = [
                0 => TextManager::_('Puvodni_plan'),
                1 => TextManager::_('Upraveny_plan'),
                2 => TextManager::_('Kombinovany_plan'),
                3 => TextManager::_('Kapacity_dle_smen')
            ];
        } else {
            $data = [
                0 => TextManager::_('Puvodni_plan'),
                3 => TextManager::_('Kapacity_dle_smen')
            ];
        }

        if (RonPortalSettings::getIntValue('kapacity_povolitsloty')) {
            $data[4] = TextManager::_('Prehled_podle_slotu');
        }

        if (RonPortalSettings::getIntValue('planovanipodminek')) {
            $data[5] = TextManager::_('Planovani_podminek');
        }

        echo '<div class="filterrow" id="filter_urovenschvaleni">';
        echo '<span class="filtercaption"></span>';
        LinksList::renderLinks($data,
            NastaveniUzivatele::getUserSettingsItem($this ->database, self::REZIM_UPRAV, RonPortalSettings::getIntValue('kapacity_rezim')),
            '?menuid=kapacity&rezim=', '', false);
        echo "</div>\n";
    }


    public function renderSkutecneAbsence()
    {
        echo '<div class="filterrow" id="filter_urovenschvaleni">';
        echo '<span class="filtercaption"></span>';

        if (KapacityController::getZobrazitSkuteneAbsence()) {
            echo "<a href='?menuid=kapacity&skutecneabsence=0'>" . TextManager::_('Skryt_skutecne_absence') . "</a>";
        } else {
            echo "<a href='?menuid=kapacity&skutecneabsence=1'>" . TextManager::_('Zobrazit_skutecne_absence') . "</a>";
        }

        echo "</div>\n";
    }


    public function renderFilters()
    {
        parent::renderFilters();

        if (User::isAuthenticated()) {
            $this->renderRezimZobrazeni(); // prepinani zobrazeni
        }

        if ($this ->zobrazitLinkSkutecneAbsence) {
            $this ->renderSkutecneAbsence();
        }
    }

}
